# coding: utf-8

"""
Waybiller External API - with fixes

The **Waybiller External API** is a feature that allows companies to access **Waybiller** data as JSON objects and create **Waybiller** instances out of their own data.  To make integration easier for the companies, the external API provides mapping support - it is possible to create company-specific mappings for object identifiers (such as destination and origin).  These mappings will be used for representing companies data from external API, and for converting the values during the creation of **Waybiller** instances (such as transport orders and waybills).  Most of the API responses contain mapped values, which may be null if the company doesn't have a mapping for this object.  Unique **Waybiller** identifiers and values can be accessed via the `raw_data` key.  The API is HTTPS and JSON based.  ### Pagination  By default, list endpoint responses are presented in pages of 30 items.  It is possible to control the page size using the `limit` parameter: `/external-api/<some-list-endpoint>/?limit=<number>`, where `<number>` is an integer between 1 and 1000.

The version of the OpenAPI document: v1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing_extensions import Annotated, Self

from pywaybiller.openapi_client.models.role_enum import RoleEnum


class ExternalAPIEmployment(BaseModel):
    """
    ExternalAPIEmployment
    """  # noqa: E501

    id: Annotated[int, Field(strict=True, ge=1)] = Field(
        description="Unique identifier of the employment"
    )
    name: Annotated[str, Field(strict=True, max_length=255)] = Field(
        description="Full name of the employee"
    )
    email: Annotated[str, Field(strict=True, max_length=254)] = Field(
        description="Email address of the employee"
    )
    user_id: Annotated[str, Field(strict=True, max_length=10)] = Field(
        description="Unique identifier of the employee's user account in Waybiller"
    )
    role: RoleEnum = Field(
        description="User's role within the company  * `manager` - Manager * `project_manager` - Project Manager * `object_manager` - Object Manager * `dispatcher` - Dispatcher * `driver` - Driver * `acceptor` - Acceptor * `loader_operator` - Loader operator"
    )
    obsolete: StrictBool = Field(
        description="Whether the employment has been deactivated"
    )
    company_name: Annotated[str, Field(strict=True, max_length=64)] = Field(
        description="Name of the employing company"
    )
    company_reg_code: Annotated[str, Field(strict=True, max_length=16)] = Field(
        description="Registration code of the employing company"
    )
    subcontractor_company_name: Optional[
        Annotated[str, Field(strict=True, max_length=64)]
    ] = Field(description="Name of the subcontractor company, if applicable")
    subcontractor_company_reg_code: Optional[
        Annotated[str, Field(strict=True, max_length=16)]
    ] = Field(
        description="Registration code of the subcontractor company, if applicable"
    )
    __properties: ClassVar[List[str]] = [
        "id",
        "name",
        "email",
        "user_id",
        "role",
        "obsolete",
        "company_name",
        "company_reg_code",
        "subcontractor_company_name",
        "subcontractor_company_reg_code",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExternalAPIEmployment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set(
            [
                "id",
                "name",
                "email",
                "user_id",
                "role",
                "obsolete",
                "company_name",
                "company_reg_code",
                "subcontractor_company_name",
                "subcontractor_company_reg_code",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if subcontractor_company_name (nullable) is None
        # and model_fields_set contains the field
        if (
            self.subcontractor_company_name is None
            and "subcontractor_company_name" in self.model_fields_set
        ):
            _dict["subcontractor_company_name"] = None

        # set to None if subcontractor_company_reg_code (nullable) is None
        # and model_fields_set contains the field
        if (
            self.subcontractor_company_reg_code is None
            and "subcontractor_company_reg_code" in self.model_fields_set
        ):
            _dict["subcontractor_company_reg_code"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExternalAPIEmployment from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "name": obj.get("name"),
                "email": obj.get("email"),
                "user_id": obj.get("user_id"),
                "role": obj.get("role"),
                "obsolete": obj.get("obsolete")
                if obj.get("obsolete") is not None
                else False,
                "company_name": obj.get("company_name"),
                "company_reg_code": obj.get("company_reg_code"),
                "subcontractor_company_name": obj.get("subcontractor_company_name"),
                "subcontractor_company_reg_code": obj.get(
                    "subcontractor_company_reg_code"
                ),
            }
        )
        return _obj
