# coding: utf-8

"""
Waybiller External API - with fixes

The **Waybiller External API** is a feature that allows companies to access **Waybiller** data as JSON objects and create **Waybiller** instances out of their own data.  To make integration easier for the companies, the external API provides mapping support - it is possible to create company-specific mappings for object identifiers (such as destination and origin).  These mappings will be used for representing companies data from external API, and for converting the values during the creation of **Waybiller** instances (such as transport orders and waybills).  Most of the API responses contain mapped values, which may be null if the company doesn't have a mapping for this object.  Unique **Waybiller** identifiers and values can be accessed via the `raw_data` key.  The API is HTTPS and JSON based.  ### Pagination  By default, list endpoint responses are presented in pages of 30 items.  It is possible to control the page size using the `limit` parameter: `/external-api/<some-list-endpoint>/?limit=<number>`, where `<number>` is an integer between 1 and 1000.

The version of the OpenAPI document: v1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing_extensions import Annotated, Self


class ExternalAPILoaderActionLogRawData(BaseModel):
    """
    ExternalAPILoaderActionLogRawData
    """  # noqa: E501

    log_id: Annotated[int, Field(strict=True, ge=1)] = Field(
        description="Unique identifier of the loader action log"
    )
    loader_operator_user_id: Annotated[int, Field(strict=True, ge=1)] = Field(
        description="Unique identifier of the user operating the loader"
    )
    origin_id: Annotated[int, Field(strict=True, ge=1)] = Field(
        description="Unique identifier of the origin where the action was performed"
    )
    order_id: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(
        description="Unique identifier of the associated order, if applicable"
    )
    vehicle_id: Optional[StrictInt] = Field(
        description="Unique identifier of the vehicle involved in the action, if applicable"
    )
    loader_unit_id: Annotated[int, Field(strict=True, ge=1)] = Field(
        description="Unique identifier of the used loader unit"
    )
    assortment_id: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(
        description="Unique identifier of the loaded assortment, if applicable"
    )
    subset_id: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(
        description="Unique identifier of the assortment subset, if applicable"
    )
    __properties: ClassVar[List[str]] = [
        "log_id",
        "loader_operator_user_id",
        "origin_id",
        "order_id",
        "vehicle_id",
        "loader_unit_id",
        "assortment_id",
        "subset_id",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExternalAPILoaderActionLogRawData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set(
            [
                "log_id",
                "loader_operator_user_id",
                "origin_id",
                "order_id",
                "vehicle_id",
                "loader_unit_id",
                "assortment_id",
                "subset_id",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if order_id (nullable) is None
        # and model_fields_set contains the field
        if self.order_id is None and "order_id" in self.model_fields_set:
            _dict["order_id"] = None

        # set to None if vehicle_id (nullable) is None
        # and model_fields_set contains the field
        if self.vehicle_id is None and "vehicle_id" in self.model_fields_set:
            _dict["vehicle_id"] = None

        # set to None if assortment_id (nullable) is None
        # and model_fields_set contains the field
        if self.assortment_id is None and "assortment_id" in self.model_fields_set:
            _dict["assortment_id"] = None

        # set to None if subset_id (nullable) is None
        # and model_fields_set contains the field
        if self.subset_id is None and "subset_id" in self.model_fields_set:
            _dict["subset_id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExternalAPILoaderActionLogRawData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "log_id": obj.get("log_id"),
                "loader_operator_user_id": obj.get("loader_operator_user_id"),
                "origin_id": obj.get("origin_id"),
                "order_id": obj.get("order_id"),
                "vehicle_id": obj.get("vehicle_id"),
                "loader_unit_id": obj.get("loader_unit_id"),
                "assortment_id": obj.get("assortment_id"),
                "subset_id": obj.get("subset_id"),
            }
        )
        return _obj
