# coding: utf-8

"""
Waybiller External API - with fixes

The **Waybiller External API** is a feature that allows companies to access **Waybiller** data as JSON objects and create **Waybiller** instances out of their own data.  To make integration easier for the companies, the external API provides mapping support - it is possible to create company-specific mappings for object identifiers (such as destination and origin).  These mappings will be used for representing companies data from external API, and for converting the values during the creation of **Waybiller** instances (such as transport orders and waybills).  Most of the API responses contain mapped values, which may be null if the company doesn't have a mapping for this object.  Unique **Waybiller** identifiers and values can be accessed via the `raw_data` key.  The API is HTTPS and JSON based.  ### Pagination  By default, list endpoint responses are presented in pages of 30 items.  It is possible to control the page size using the `limit` parameter: `/external-api/<some-list-endpoint>/?limit=<number>`, where `<number>` is an integer between 1 and 1000.

The version of the OpenAPI document: v1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import date
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Annotated, Self

from pywaybiller.openapi_client.models.external_api_transport_order_raw_data_list import (
    ExternalAPITransportOrderRawDataList,
)


class ExternalAPITransportOrderList(BaseModel):
    """
    ExternalAPITransportOrderList
    """  # noqa: E501

    transport_order_id: StrictStr
    transport_date: Optional[date]
    origin_id: Optional[StrictStr] = Field(
        description="Unique identifier of the origin in your system"
    )
    origin_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    origin_address: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    destination_id: Optional[StrictStr] = Field(
        description="Unique identifier of the destination in your system"
    )
    destination_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = (
        None
    )
    destination_address: Optional[
        Annotated[str, Field(strict=True, max_length=255)]
    ] = None
    assortment_name: StrictStr
    transportation_company_name: Optional[
        Annotated[str, Field(strict=True, max_length=64)]
    ] = None
    truck_reg_number: Optional[Annotated[str, Field(strict=True, max_length=16)]] = None
    trailer_reg_number: Optional[Annotated[str, Field(strict=True, max_length=16)]] = (
        None
    )
    waybills_ids: List[StrictInt]
    raw_data: ExternalAPITransportOrderRawDataList = Field(
        description="The IDs of the Waybiller internal objects"
    )
    __properties: ClassVar[List[str]] = [
        "transport_order_id",
        "transport_date",
        "origin_id",
        "origin_name",
        "origin_address",
        "destination_id",
        "destination_name",
        "destination_address",
        "assortment_name",
        "transportation_company_name",
        "truck_reg_number",
        "trailer_reg_number",
        "waybills_ids",
        "raw_data",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExternalAPITransportOrderList from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set(
            [
                "transport_order_id",
                "transport_date",
                "assortment_name",
                "waybills_ids",
                "raw_data",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of raw_data
        if self.raw_data:
            _dict["raw_data"] = self.raw_data.to_dict()
        # set to None if transport_date (nullable) is None
        # and model_fields_set contains the field
        if self.transport_date is None and "transport_date" in self.model_fields_set:
            _dict["transport_date"] = None

        # set to None if origin_id (nullable) is None
        # and model_fields_set contains the field
        if self.origin_id is None and "origin_id" in self.model_fields_set:
            _dict["origin_id"] = None

        # set to None if destination_id (nullable) is None
        # and model_fields_set contains the field
        if self.destination_id is None and "destination_id" in self.model_fields_set:
            _dict["destination_id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExternalAPITransportOrderList from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "transport_order_id": obj.get("transport_order_id"),
                "transport_date": obj.get("transport_date"),
                "origin_id": obj.get("origin_id"),
                "origin_name": obj.get("origin_name"),
                "origin_address": obj.get("origin_address"),
                "destination_id": obj.get("destination_id"),
                "destination_name": obj.get("destination_name"),
                "destination_address": obj.get("destination_address"),
                "assortment_name": obj.get("assortment_name"),
                "transportation_company_name": obj.get("transportation_company_name"),
                "truck_reg_number": obj.get("truck_reg_number"),
                "trailer_reg_number": obj.get("trailer_reg_number"),
                "waybills_ids": obj.get("waybills_ids"),
                "raw_data": ExternalAPITransportOrderRawDataList.from_dict(
                    obj["raw_data"]
                )
                if obj.get("raw_data") is not None
                else None,
            }
        )
        return _obj
