# coding: utf-8

"""
Waybiller External API - with fixes

The **Waybiller External API** is a feature that allows companies to access **Waybiller** data as JSON objects and create **Waybiller** instances out of their own data.  To make integration easier for the companies, the external API provides mapping support - it is possible to create company-specific mappings for object identifiers (such as destination and origin).  These mappings will be used for representing companies data from external API, and for converting the values during the creation of **Waybiller** instances (such as transport orders and waybills).  Most of the API responses contain mapped values, which may be null if the company doesn't have a mapping for this object.  Unique **Waybiller** identifiers and values can be accessed via the `raw_data` key.  The API is HTTPS and JSON based.  ### Pagination  By default, list endpoint responses are presented in pages of 30 items.  It is possible to control the page size using the `limit` parameter: `/external-api/<some-list-endpoint>/?limit=<number>`, where `<number>` is an integer between 1 and 1000.

The version of the OpenAPI document: v1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing_extensions import Annotated, Self

from pywaybiller.openapi_client.models.external_api_vehicle_location_data_raw_data import (
    ExternalAPIVehicleLocationDataRawData,
)
from pywaybiller.openapi_client.models.external_api_vehicle_location_data_vehicle_location_data_inner_value import (
    ExternalAPIVehicleLocationDataVehicleLocationDataInnerValue,
)


class ExternalAPIVehicleLocationData(BaseModel):
    """
    ExternalAPIVehicleLocationData
    """  # noqa: E501

    truck_reg_number: Annotated[str, Field(strict=True, max_length=16)] = Field(
        description="Vehicle registration number"
    )
    waybill_number: Annotated[str, Field(strict=True, max_length=16)] = Field(
        description="Unique waybill reference number"
    )
    transportation_company_name: Annotated[str, Field(strict=True, max_length=64)] = (
        Field(description="Name of the transport service provider")
    )
    receiver_company_name: StrictStr = Field(
        description="Name of the receiving company"
    )
    origin_company_name: Annotated[str, Field(strict=True, max_length=64)] = Field(
        description="Name of the shipping company"
    )
    origin_name: Annotated[str, Field(strict=True, max_length=255)] = Field(
        description="Name of the shipping location"
    )
    destination_name: Annotated[str, Field(strict=True, max_length=255)] = Field(
        description="Name of the delivery destination"
    )
    raw_data: ExternalAPIVehicleLocationDataRawData = Field(
        description="The IDs of the Waybiller internal objects"
    )
    vehicle_location_data: List[
        Dict[str, ExternalAPIVehicleLocationDataVehicleLocationDataInnerValue]
    ] = Field(description="Collection of vehicle location tracking points")
    __properties: ClassVar[List[str]] = [
        "truck_reg_number",
        "waybill_number",
        "transportation_company_name",
        "receiver_company_name",
        "origin_company_name",
        "origin_name",
        "destination_name",
        "raw_data",
        "vehicle_location_data",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExternalAPIVehicleLocationData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set(
            [
                "truck_reg_number",
                "waybill_number",
                "transportation_company_name",
                "receiver_company_name",
                "origin_company_name",
                "origin_name",
                "destination_name",
                "raw_data",
                "vehicle_location_data",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of raw_data
        if self.raw_data:
            _dict["raw_data"] = self.raw_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in vehicle_location_data (list)
        _items = []
        if self.vehicle_location_data:
            for _item_vehicle_location_data in self.vehicle_location_data:
                if _item_vehicle_location_data:
                    _items.append(_item_vehicle_location_data.to_dict())
            _dict["vehicle_location_data"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExternalAPIVehicleLocationData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "truck_reg_number": obj.get("truck_reg_number"),
                "waybill_number": obj.get("waybill_number"),
                "transportation_company_name": obj.get("transportation_company_name"),
                "receiver_company_name": obj.get("receiver_company_name"),
                "origin_company_name": obj.get("origin_company_name"),
                "origin_name": obj.get("origin_name"),
                "destination_name": obj.get("destination_name"),
                "raw_data": ExternalAPIVehicleLocationDataRawData.from_dict(
                    obj["raw_data"]
                )
                if obj.get("raw_data") is not None
                else None,
                "vehicle_location_data": [
                    Dict[
                        str, ExternalAPIVehicleLocationDataVehicleLocationDataInnerValue
                    ].from_dict(_item)
                    for _item in obj["vehicle_location_data"]
                ]
                if obj.get("vehicle_location_data") is not None
                else None,
            }
        )
        return _obj
