# coding: utf-8

"""
Waybiller External API - with fixes

The **Waybiller External API** is a feature that allows companies to access **Waybiller** data as JSON objects and create **Waybiller** instances out of their own data.  To make integration easier for the companies, the external API provides mapping support - it is possible to create company-specific mappings for object identifiers (such as destination and origin).  These mappings will be used for representing companies data from external API, and for converting the values during the creation of **Waybiller** instances (such as transport orders and waybills).  Most of the API responses contain mapped values, which may be null if the company doesn't have a mapping for this object.  Unique **Waybiller** identifiers and values can be accessed via the `raw_data` key.  The API is HTTPS and JSON based.  ### Pagination  By default, list endpoint responses are presented in pages of 30 items.  It is possible to control the page size using the `limit` parameter: `/external-api/<some-list-endpoint>/?limit=<number>`, where `<number>` is an integer between 1 and 1000.

The version of the OpenAPI document: v1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing_extensions import Self

from pywaybiller.openapi_client.models.external_api_waybill_row_raw_data import (
    ExternalAPIWaybillRowRawData,
)


class ExternalAPIWaybillRawData(BaseModel):
    """
    ExternalAPIWaybillRawData
    """  # noqa: E501

    waybill_id: StrictInt = Field(description="The ID of the waybill.")
    truck_id: Optional[StrictInt] = Field(description="The ID of the truck.")
    driver_user_id: Optional[StrictInt] = Field(description="The ID of the driver.")
    origin_id: StrictInt = Field(description="The ID of the origin.")
    destination_id: Optional[StrictInt] = Field(
        description="The ID of the destination."
    )
    rows: List[ExternalAPIWaybillRowRawData] = Field(description="Waybill rows.")
    user_defined_fields: Optional[Dict[str, Any]] = Field(
        description="User defined fields."
    )
    __properties: ClassVar[List[str]] = [
        "waybill_id",
        "truck_id",
        "driver_user_id",
        "origin_id",
        "destination_id",
        "rows",
        "user_defined_fields",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExternalAPIWaybillRawData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set(
            [
                "waybill_id",
                "truck_id",
                "driver_user_id",
                "origin_id",
                "destination_id",
                "rows",
                "user_defined_fields",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in rows (list)
        _items = []
        if self.rows:
            for _item_rows in self.rows:
                if _item_rows:
                    _items.append(_item_rows.to_dict())
            _dict["rows"] = _items
        # set to None if truck_id (nullable) is None
        # and model_fields_set contains the field
        if self.truck_id is None and "truck_id" in self.model_fields_set:
            _dict["truck_id"] = None

        # set to None if driver_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.driver_user_id is None and "driver_user_id" in self.model_fields_set:
            _dict["driver_user_id"] = None

        # set to None if destination_id (nullable) is None
        # and model_fields_set contains the field
        if self.destination_id is None and "destination_id" in self.model_fields_set:
            _dict["destination_id"] = None

        # set to None if user_defined_fields (nullable) is None
        # and model_fields_set contains the field
        if (
            self.user_defined_fields is None
            and "user_defined_fields" in self.model_fields_set
        ):
            _dict["user_defined_fields"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExternalAPIWaybillRawData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "waybill_id": obj.get("waybill_id"),
                "truck_id": obj.get("truck_id"),
                "driver_user_id": obj.get("driver_user_id"),
                "origin_id": obj.get("origin_id"),
                "destination_id": obj.get("destination_id"),
                "rows": [
                    ExternalAPIWaybillRowRawData.from_dict(_item)
                    for _item in obj["rows"]
                ]
                if obj.get("rows") is not None
                else None,
                "user_defined_fields": obj.get("user_defined_fields"),
            }
        )
        return _obj
